@@ -15,4 +15,11 @@
     dsp = ImageInTerminal.TerminalGraphicDisplay(io)
     display(dsp, MIME("image/png"), bytes)
     @test length(read(io, String)) > 5_000
+
+    struct Foo end
+    Base.show(io::IO, ::MIME"image/png", ::Foo) =
+        FileIO.save(Stream{format"PNG"}(io), FileIO.load(fn))
+    dsp = ImageInTerminal.TerminalGraphicDisplay(io)
+    display(dsp, MIME("image/png"), Foo())
+    @test length(read(io, String)) > 5_000
 end
